#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.features.footer.interfaces import IDefaultFooterRendererSettings, IDefaultFooterMenu
from pyams_content.component.association.interfaces import ASSOCIATION_CONTAINER_KEY
from pyams_content.features.menu.interfaces import IMenuLinksContainer, IMenuLinksContainerTarget
from zope.location.interfaces import ISublocations

# import packages
from persistent import Persistent
from pyams_content.features.menu import Menu
from pyams_utils.adapter import adapter_config, get_annotation_adapter, ContextAdapter
from zope.interface import implementer
from zope.location import Location
from zope.schema.fieldproperty import FieldProperty


#
# Default footer renderer settings
#

DEFAULT_FOOTER_SOCIAL_LINKS_KEY = '{0}::social'.format(ASSOCIATION_CONTAINER_KEY)
DEFAULT_FOOTER_SITES_LINKS_KEY = '{0}::sites'.format(ASSOCIATION_CONTAINER_KEY)
DEFAULT_FOOTER_RESOURCES_LINKS_KEY = '{0}::resources'.format(ASSOCIATION_CONTAINER_KEY)
DEFAULT_FOOTER_CONTACTS_LINKS_KEY = '{0}::contacts'.format(ASSOCIATION_CONTAINER_KEY)
DEFAULT_FOOTER_APPS_LINKS_KEY = '{0}::apps'.format(ASSOCIATION_CONTAINER_KEY)
DEFAULT_FOOTER_LEGAL_LINKS_KEY = '{0}::legal'.format(ASSOCIATION_CONTAINER_KEY)


@implementer(IDefaultFooterRendererSettings, IMenuLinksContainerTarget)
class DefaultFooterRendererSettings(Persistent, Location):
    """Default footer renderer settings"""

    social_links_header = FieldProperty(IDefaultFooterRendererSettings['social_links_header'])
    sites_links_header = FieldProperty(IDefaultFooterRendererSettings['sites_links_header'])
    resources_links_header = FieldProperty(IDefaultFooterRendererSettings['resources_links_header'])
    contacts_links_header = FieldProperty(IDefaultFooterRendererSettings['contacts_links_header'])
    apps_links_header = FieldProperty(IDefaultFooterRendererSettings['apps_links_header'])
    legal_links_signature = FieldProperty(IDefaultFooterRendererSettings['legal_links_signature'])

    @property
    def social_links(self):
        return get_annotation_adapter(self, DEFAULT_FOOTER_SOCIAL_LINKS_KEY, Menu,
                                      markers=IDefaultFooterMenu, name='++ass++social')

    @property
    def sites_links(self):
        return get_annotation_adapter(self, DEFAULT_FOOTER_SITES_LINKS_KEY, Menu,
                                      markers=IDefaultFooterMenu, name='++ass++sites')

    @property
    def resources_links(self):
        return get_annotation_adapter(self, DEFAULT_FOOTER_RESOURCES_LINKS_KEY, Menu,
                                      markers=IDefaultFooterMenu, name='++ass++resources')

    @property
    def contacts_links(self):
        return get_annotation_adapter(self, DEFAULT_FOOTER_CONTACTS_LINKS_KEY, Menu,
                                      markers=IDefaultFooterMenu, name='++ass++contacts')

    @property
    def apps_links(self):
        return get_annotation_adapter(self, DEFAULT_FOOTER_APPS_LINKS_KEY, Menu,
                                      markers=IDefaultFooterMenu, name='++ass++apps')

    @property
    def legal_links(self):
        return get_annotation_adapter(self, DEFAULT_FOOTER_LEGAL_LINKS_KEY, Menu,
                                      markers=IDefaultFooterMenu, name='++ass++legal')


@adapter_config(name='social', context=IDefaultFooterRendererSettings, provides=IMenuLinksContainer)
def default_footer_social_links_adapter(context):
    """Default footer social links factory"""
    return context.social_links


@adapter_config(name='sites', context=IDefaultFooterRendererSettings, provides=IMenuLinksContainer)
def default_footer_sites_links_factory(context):
    """Default footer sites links factory"""
    return context.sites_links


@adapter_config(name='resources', context=IDefaultFooterRendererSettings, provides=IMenuLinksContainer)
def default_footer_resources_links_factory(context):
    """Default footer resources links factory"""
    return context.resources_links


@adapter_config(name='contacts', context=IDefaultFooterRendererSettings, provides=IMenuLinksContainer)
def default_footer_contacts_links_factory(context):
    """Default footer contacts links factory"""
    return context.contacts_links


@adapter_config(name='apps', context=IDefaultFooterRendererSettings, provides=IMenuLinksContainer)
def default_footer_apps_links_factory(context):
    """Default footer applications links factory"""
    return context.apps_links


@adapter_config(name='legal', context=IDefaultFooterRendererSettings, provides=IMenuLinksContainer)
def default_footer_legal_links_factory(context):
    """Default footer legal links factory"""
    return context.legal_links


@adapter_config(name='links', context=IDefaultFooterRendererSettings, provides=ISublocations)
class DefaultFooterRendererSettingsSublocations(ContextAdapter):
    """Default footer renderer settings sub-locations adapter"""

    def sublocations(self):
        return self.context.social_links.values() + \
               self.context.sites_links.values() + \
               self.context.resources_links.values() + \
               self.context.contacts_links.values() + \
               self.context.apps_links.values() + \
               self.context.legal_links.values()
